package itso.bank.facade.ejb;

import itso.bank.model.ejb.Account;
import itso.bank.model.ejb.Credit;
import itso.bank.model.ejb.Customer;
import itso.bank.model.ejb.Debit;
import itso.bank.model.ejb.Transaction;
import itso.bank.model.ejb.controller.AccountManager;
import itso.bank.model.ejb.controller.CreditManager;
import itso.bank.model.ejb.controller.CustomerManager;
import itso.bank.model.ejb.controller.DebitManager;

import java.util.Collection;
import java.util.Iterator;
import java.util.Set;

import javax.ejb.EJB;
import javax.ejb.Stateless;

@Stateless 
public class BankFacade implements BankFacadeRemote {
	private CustomerManager cm = new CustomerManager();
	private AccountManager am = new AccountManager();
	private CreditManager crdm = new CreditManager();
	private DebitManager dbtm = new DebitManager();

	
	public Account getAccount(String accountNumber)
			throws Exception {
		Account anAccount = am.findAccountById(accountNumber);
		return anAccount;
	}

	
	public Customer getCustomer(String ssn) throws Exception {

		Customer customer = cm.findCustomerBySsn(ssn);
		return customer;
	}

	
	public void updateCustomer(String ssn, String title, String firstName,
			String lastName) throws Exception {
		Customer aCustomer = cm.findCustomerBySsn(ssn);
        //Customer aCustomer = new Customer();
        //aCustomer.setSsn(ssn);
		aCustomer.setTitle(title);
		aCustomer.setFirstname(firstName);
		aCustomer.setLastname(lastName);
		try {
			String result = cm.updateCustomer(aCustomer);
		} catch (Exception ex) {
			throw new Exception(aCustomer.getSsn());
		}
	}

	
	public Account[] getAccounts(String ssn) throws Exception {
		Customer customer = cm.findCustomerBySsn(ssn);

		Set<Account> colAccounts = customer.getAccountCollection();
		Iterator<Account> itAccounts = colAccounts.iterator();
		Account[] arrAccount = new Account[colAccounts.size()];
		int i = 0;
		while (itAccounts.hasNext()) {
			Account account = itAccounts.next();
			arrAccount[i++] = account;
		}

		return arrAccount;
	}

	
	public Transaction[] getTransactions(String accountNumber)
			throws Exception {
		Account anAccount = am.findAccountById(accountNumber);
		Collection<Transaction> setTransactions = anAccount.getLog();
		Transaction[] arrTransaction = new Transaction[setTransactions.size()];
		arrTransaction = setTransactions.toArray(arrTransaction);

		return arrTransaction;
	}

	
	protected Credit createCreditLocal(int amount) throws Exception {
		//Credit aCredit = new Credit();
		Credit aCredit = crdm.getNewCredit();
		aCredit.setAmount(amount);
		aCredit.setTranstype("Credit");
		return aCredit;
	}


	protected Debit createDebitLocal(int amount) throws Exception {
		//Debit aDebit = new Debit();
		Debit aDebit = dbtm.getNewDebit();
		aDebit.setAmount(amount);
		aDebit.setTranstype("Debit");
		return aDebit;

	}

	public void deposit(String accountNumber, int amount)
			throws Exception  {
		Account anAccount = am.findAccountById(accountNumber);

		Credit aCredit = createCreditLocal(amount);
		aCredit.setAccounts(anAccount);

		anAccount.processTransaction(aCredit);
		// Save new Transaction
		try {
			String result = crdm.createCredit(aCredit);
		} catch (Exception ex){
			throw new Exception("Couldn't persist the new credit transaction.");
		}
		// This is redundant and should not be required
		try {
			String result = am.updateAccount(anAccount);
		} catch (Exception ex) {
			throw new Exception(anAccount.getId());
		}
	}

	
	public void withdraw(String accountNumber, int amount)
			throws Exception {
		Account anAccount = am.findAccountById(accountNumber);

		Debit aDebit = createDebitLocal(amount);
		aDebit.setAccounts(anAccount);

		anAccount.processTransaction(aDebit);
		// Save new Transaction
		try {
			String result = dbtm.createDebit(aDebit);
		} catch (Exception ex){
			throw new Exception("Couldn't persist the new debit transaction.");
		}
		// This is redundant and should not be required
		try {
			String result = am.updateAccount(anAccount);
		} catch (Exception ex) {
			throw new Exception(anAccount.getId());
		}
	}

	
	public void transfer(String debitAccountNumber, String creditAccountNumber,
			int amount) throws Exception {
		withdraw(debitAccountNumber, amount);
		deposit(creditAccountNumber, amount);
	}
}


