/**
 * 
 */
package itso.bank.model.ejb.controller;

import com.ibm.jpa.web.JPAManager;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.RollbackException;

import com.ibm.jpa.web.NamedQueryTarget;
import com.ibm.jpa.web.Action;
import javax.persistence.Persistence;
import itso.bank.model.ejb.Account;
import java.lang.String;
import java.util.List;
import javax.persistence.Query;

/**
 * @author jarek
 *
 */
@JPAManager(targetEntity=itso.bank.model.ejb.Account.class)
@SuppressWarnings("unchecked")
public class AccountManager {

	public AccountManager() {
	
	}

	private EntityManager getEntityManager() {
		EntityManagerFactory emf = Persistence
				.createEntityManagerFactory("BankEJB3");
		return emf.createEntityManager();
	}

	@Action(Action.ACTION_TYPE.CREATE)
	public String createAccount(Account account) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.getTransaction().begin();
			em.persist(account);
			em.getTransaction().commit();
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.DELETE)
	public String deleteAccount(Account account) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.getTransaction().begin();
			account = em.merge(account);
			em.remove(account);
			em.getTransaction().commit();
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.UPDATE)
	public String updateAccount(Account account) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.getTransaction().begin();
			account = em.merge(account);
			em.getTransaction().commit();
		} catch (RollbackException rex) {
			// Ignore DSRA9350E Operation Connection.commit is not allowed
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.FIND)
	public Account findAccountById(String id) {
		Account account = null;
		EntityManager em = getEntityManager();
		try {
			account = (Account) em.find(Account.class, id);
		} finally {
			em.close();
		}
		return account;
	}

	@Action(Action.ACTION_TYPE.NEW)
	public Account getNewAccount() {
		Account account = new Account();
		return account;
	}

	@NamedQueryTarget("getAccount")
	public List<Account> getAccount() {
		EntityManager em = getEntityManager();
		List<Account> results = null;
		try {
			Query query = em.createNamedQuery("getAccount");
			results = (List<Account>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getAccountOrdered")
	public List<Account> getAccountOrdered() {
		EntityManager em = getEntityManager();
		List<Account> results = null;
		try {
			Query query = em.createNamedQuery("getAccountOrdered");
			results = (List<Account>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getAccountByBalance")
	public List<Account> getAccountByBalance(int balance) {
		EntityManager em = getEntityManager();
		List<Account> results = null;
		try {
			Query query = em.createNamedQuery("getAccountByBalance");
			query.setParameter("balance", balance);
			results = (List<Account>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	} 
 }