/**
 * 
 */
package itso.bank.model.ejb.controller;

import com.ibm.jpa.web.JPAManager;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.RollbackException;

import com.ibm.jpa.web.NamedQueryTarget;
import com.ibm.jpa.web.Action;
import javax.persistence.Persistence;
import itso.bank.model.ejb.Credit;
import java.lang.String;
import java.util.List;
import javax.persistence.Query;
import javax.persistence.TemporalType;
import java.util.Date;

/**
 * @author jarek
 *
 */
@JPAManager(targetEntity=itso.bank.model.ejb.Credit.class)
@SuppressWarnings("unchecked")
public class CreditManager {

	public CreditManager() {
	
	}

	private EntityManager getEntityManager() {
		EntityManagerFactory emf = Persistence
				.createEntityManagerFactory("BankEJB3");
		return emf.createEntityManager();
	}

	@Action(Action.ACTION_TYPE.CREATE)
	public String createCredit(Credit credit) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.getTransaction().begin();
			em.persist(credit);
			em.getTransaction().commit();
		} catch (RollbackException rex) {
			// Ignore DSRA9350E Operation Connection.commit is not allowed
	
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.DELETE)
	public String deleteCredit(Credit credit) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.getTransaction().begin();
			credit = em.merge(credit);
			em.remove(credit);
			em.getTransaction().commit();
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.UPDATE)
	public String updateCredit(Credit credit) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.getTransaction().begin();
			credit = em.merge(credit);
			em.getTransaction().commit();
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.FIND)
	public Credit findCreditById(String id) {
		Credit credit = null;
		EntityManager em = getEntityManager();
		try {
			credit = (Credit) em.find(Credit.class, id);
		} finally {
			em.close();
		}
		return credit;
	}

	@Action(Action.ACTION_TYPE.NEW)
	public Credit getNewCredit() {
		Credit credit = new Credit();
		return credit;
	}

	@NamedQueryTarget("getCredit")
	public List<Credit> getCredit() {
		EntityManager em = getEntityManager();
		List<Credit> results = null;
		try {
			Query query = em.createNamedQuery("getCredit");
			results = (List<Credit>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCreditOrdered")
	public List<Credit> getCreditOrdered() {
		EntityManager em = getEntityManager();
		List<Credit> results = null;
		try {
			Query query = em.createNamedQuery("getCreditOrdered");
			results = (List<Credit>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCreditByAmount")
	public List<Credit> getCreditByAmount(int amount) {
		EntityManager em = getEntityManager();
		List<Credit> results = null;
		try {
			Query query = em.createNamedQuery("getCreditByAmount");
			query.setParameter("amount", amount);
			results = (List<Credit>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCreditByTranstype")
	public List<Credit> getCreditByTranstype(String transtype) {
		EntityManager em = getEntityManager();
		List<Credit> results = null;
		try {
			Query query = em.createNamedQuery("getCreditByTranstype");
			query.setParameter("transtype", transtype);
			results = (List<Credit>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCreditByTranstime")
	public List<Credit> getCreditByTranstime(Date transtime) {
		EntityManager em = getEntityManager();
		List<Credit> results = null;
		try {
			Query query = em.createNamedQuery("getCreditByTranstime");
			query.setParameter("transtime", transtime, TemporalType.TIMESTAMP);
			results = (List<Credit>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	} 
 }