/**
 * 
 */
package itso.bank.model.ejb.controller;

import itso.bank.model.ejb.Customer;

import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import javax.persistence.Query;
import javax.persistence.RollbackException;

import com.ibm.jpa.web.Action;
import com.ibm.jpa.web.JPAManager;
import com.ibm.jpa.web.NamedQueryTarget;

/**
 * @author jarek
 * 
 */
@JPAManager(targetEntity = itso.bank.model.ejb.Customer.class)
@SuppressWarnings("unchecked")
public class CustomerManager {

	public CustomerManager() {

	}

	private EntityManager getEntityManager() {
		EntityManagerFactory emf = Persistence
				.createEntityManagerFactory("BankEJB3");
		return emf.createEntityManager();
	}

	@Action(Action.ACTION_TYPE.CREATE)
	public String createCustomer(Customer customer) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.getTransaction().begin();
			em.persist(customer);
			em.getTransaction().commit();
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.DELETE)
	public String deleteCustomer(Customer customer) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.getTransaction().begin();
			customer = em.merge(customer);
			em.remove(customer);
			em.getTransaction().commit();
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.UPDATE)
	public String updateCustomer(Customer customer) throws Exception {
		EntityManager em = getEntityManager();

		try {
			if (em.getTransaction().isActive()) {
				customer = em.merge(customer);
			} else {
				em.getTransaction().begin();
				customer = em.merge(customer);
				em.getTransaction().commit();
			}
		} catch (RollbackException rex) {
			// Ignore DSRA9350E Operation Connection.commit is not allowed
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.FIND)
	public Customer findCustomerBySsn(String ssn) {
		Customer customer = null;
		EntityManager em = getEntityManager();
		try {
			customer = (Customer) em.find(Customer.class, ssn);
		} finally {
			em.close();
		}
		return customer;
	}

	@Action(Action.ACTION_TYPE.NEW)
	public Customer getNewCustomer() {
		Customer customer = new Customer();
		return customer;
	}

	@NamedQueryTarget("getCustomer")
	public List<Customer> getCustomer() {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomer");
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCustomerOrdered")
	public List<Customer> getCustomerOrdered() {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomerOrdered");
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCustomerByLastname")
	public List<Customer> getCustomerByLastname(String lastname) {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomerByLastname");
			query.setParameter("lastname", lastname);
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCustomerByTitle")
	public List<Customer> getCustomerByTitle(String title) {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomerByTitle");
			query.setParameter("title", title);
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getCustomerByFirstname")
	public List<Customer> getCustomerByFirstname(String firstname) {
		EntityManager em = getEntityManager();
		List<Customer> results = null;
		try {
			Query query = em.createNamedQuery("getCustomerByFirstname");
			query.setParameter("firstname", firstname);
			results = (List<Customer>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}
}