/**
 * 
 */
package itso.bank.model.ejb.controller;

import com.ibm.jpa.web.JPAManager;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.RollbackException;

import com.ibm.jpa.web.NamedQueryTarget;
import com.ibm.jpa.web.Action;
import javax.persistence.Persistence;
import itso.bank.model.ejb.Debit;
import java.lang.String;
import java.util.List;
import javax.persistence.Query;
import javax.persistence.TemporalType;
import java.util.Date;

/**
 * @author jarek
 *
 */
@JPAManager(targetEntity=itso.bank.model.ejb.Debit.class)
@SuppressWarnings("unchecked")
public class DebitManager {

	public DebitManager() {
	
	}

	private EntityManager getEntityManager() {
		EntityManagerFactory emf = Persistence
				.createEntityManagerFactory("BankEJB3");
		return emf.createEntityManager();
	}

	@Action(Action.ACTION_TYPE.CREATE)
	public String createDebit(Debit debit) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.getTransaction().begin();
			em.persist(debit);
			em.getTransaction().commit();
		} catch (RollbackException rex) {
			// Ignore DSRA9350E Operation Connection.commit is not allowed
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.DELETE)
	public String deleteDebit(Debit debit) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.getTransaction().begin();
			debit = em.merge(debit);
			em.remove(debit);
			em.getTransaction().commit();
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.UPDATE)
	public String updateDebit(Debit debit) throws Exception {
		EntityManager em = getEntityManager();
		try {
			em.getTransaction().begin();
			debit = em.merge(debit);
			em.getTransaction().commit();
		} catch (Exception ex) {
			try {
				if (em.getTransaction().isActive()) {
					em.getTransaction().rollback();
				}
			} catch (Exception e) {
				ex.printStackTrace();
				throw e;
			}
			throw ex;
		} finally {
			em.close();
		}
		return "";
	}

	@Action(Action.ACTION_TYPE.FIND)
	public Debit findDebitById(String id) {
		Debit debit = null;
		EntityManager em = getEntityManager();
		try {
			debit = (Debit) em.find(Debit.class, id);
		} finally {
			em.close();
		}
		return debit;
	}

	@Action(Action.ACTION_TYPE.NEW)
	public Debit getNewDebit() {
		Debit debit = new Debit();
		return debit;
	}

	@NamedQueryTarget("getDebit")
	public List<Debit> getDebit() {
		EntityManager em = getEntityManager();
		List<Debit> results = null;
		try {
			Query query = em.createNamedQuery("getDebit");
			results = (List<Debit>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getDebitOrdered")
	public List<Debit> getDebitOrdered() {
		EntityManager em = getEntityManager();
		List<Debit> results = null;
		try {
			Query query = em.createNamedQuery("getDebitOrdered");
			results = (List<Debit>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getDebitByAmount")
	public List<Debit> getDebitByAmount(int amount) {
		EntityManager em = getEntityManager();
		List<Debit> results = null;
		try {
			Query query = em.createNamedQuery("getDebitByAmount");
			query.setParameter("amount", amount);
			results = (List<Debit>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getDebitByTranstype")
	public List<Debit> getDebitByTranstype(String transtype) {
		EntityManager em = getEntityManager();
		List<Debit> results = null;
		try {
			Query query = em.createNamedQuery("getDebitByTranstype");
			query.setParameter("transtype", transtype);
			results = (List<Debit>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	}

	@NamedQueryTarget("getDebitByTranstime")
	public List<Debit> getDebitByTranstime(Date transtime) {
		EntityManager em = getEntityManager();
		List<Debit> results = null;
		try {
			Query query = em.createNamedQuery("getDebitByTranstime");
			query.setParameter("transtime", transtime, TemporalType.TIMESTAMP);
			results = (List<Debit>) query.getResultList();
		} finally {
			em.close();
		}
		return results;
	} 
 }