package itso.bank.command;

import itso.bank.facade.Bank;
import itso.bank.model.ejb.Account;
import itso.bank.model.ejb.Transaction;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;


/**
 * List transactions command. Will retrieve the account history and forward
 * to a JSP that can show this information to the user.
 * 
 * Parameters:
 * <dl>
 * <dt>accountId</dt><dd>The account to show the transaction history for</dd>
 * </dl>
 */
public class ListTransactionsCommand
		implements Command
{
	/**
	 * Retrieve the transactions for the account.
	 * 
	 * @see itso.bank.command.Command#execute(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
	 */
	public void execute(HttpServletRequest req, HttpServletResponse resp)
			throws Exception
	{
		// Parameters
		String accountId = req.getParameter("accountId");
		
		// Control logic
		Bank bank = Bank.getBank();
		
		// Response
		Account account = bank.getAccount(accountId);
		Transaction[] transactions = bank.getTransactions(accountId);

		req.setAttribute("account", account);
		req.setAttribute("transactions", transactions);
	}
	
	/**
	 * @see itso.bank.command.Command#getForwardView()
	 */
	public String getForwardView() {
		return "listTransactions.jsp";
	}
}