package itso.bank.command;


import itso.bank.facade.Bank;
import itso.bank.model.ejb.Account;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;


/**
 * Transfer command. Will perform a transfer of the specified amount
 * from one account to another.
 * 
 * Parameters:
 * <dl>
 * <dt>amount</dt><dd>The amount of cents to transfer</dd>
 * <dt>accountId</dt><dd>The debit account</dd>
 * <dt>targetAccountId</dt><dd>The credit account</dd>
 * </dl>
 */
public class TransferCommand
		implements Command
{
	/**
	 * Do the actual transfer.
	 * 
	 * @see itso.bank.command.Command#execute(javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
	 */
	public void execute(HttpServletRequest req, HttpServletResponse resp)
			throws Exception
	{
		// Parameters
		String debitAccountNumber = req.getParameter("accountId").trim();
		String creditAccountNumber = req.getParameter("targetAccountId".trim());
		String strAmount = req.getParameter("amount".trim());
		int iAmount = 0;
		
		try
		{
			iAmount = Integer.parseInt(strAmount);
		}
		catch (NumberFormatException x)
		{
			throw new Exception("Invalid Amount: " + strAmount);
		}
		
		// Control logic
		Bank bank = Bank.getBank();
		bank.transfer(debitAccountNumber, creditAccountNumber, iAmount);
		
		// Response
		Account account = bank.getAccount(debitAccountNumber);
		req.setAttribute("account", account);
	}

	/**
	 * @see itso.bank.command.Command#getForwardView()
	 */
	public String getForwardView() {
		return "accountDetails.jsp";
	}
}