package itso.bank.servlet;

import java.io.IOException;

import javax.servlet.RequestDispatcher;
import javax.servlet.Servlet;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

/**
 * Servlet to log off the current user.
 *
 * Parameters: none.
 * 
 * Output (request parameters): none. 
 * 
 * Forwards to:
 * <dl>
 * <dt>redbank.html</dt>
 * <dd>If no error occurred.</dd>
 * 
 * <dt>showException.jsp</dt>
 * <dd>If an error occurs.</dd>
 * </dl>
 */
public class Logout
		extends HttpServlet
		implements Servlet
{
	/**
	 * HTTP GET service method. Calls performTask to service requests.
	 * 
	 * @see performTask(HttpServletRequest req, HttpServletResponse resp)
	 * @see javax.servlet.http.HttpServlet#doGet(HttpServletRequest req,
	 *      HttpServletResponse resp)
	 */
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException
	{
		performTask(req, resp);
	}

	/**
	 * HTTP POST service method. Calls performTask to service requests.
	 * 
	 * @see performTask(HttpServletRequest req, HttpServletResponse resp)
	 * @see javax.servlet.http.HttpServlet#doPost(HttpServletRequest req,
	 *      HttpServletResponse resp)
	 */
	protected void doPost(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException
	{
		performTask(req, resp);
	}

	/**
	 * This method does the actual servlet processing.
	 * 
	 * @see #doGet(HttpServletRequest, HttpServletResponse)
	 * @see #doPost(HttpServletRequest, HttpServletResponse)
	 */
	private void performTask(HttpServletRequest req, HttpServletResponse resp)
	throws ServletException, IOException
	{
		try
		{
			// remove the customer number from the session
			HttpSession session = req.getSession();
			session.removeAttribute("customerNumber");
			session.invalidate();
			
			// Call the presentation renderer
			ServletContext ctx = getServletContext();
			RequestDispatcher disp = ctx.getRequestDispatcher("redbank.html");
			disp.forward(req, resp);
		}
		catch (Exception e)
		{
			// set up error information and forward to the error page
			req.setAttribute("message", e.getMessage());
			req.setAttribute("forward", "index.html");
			ServletContext ctx = getServletContext();
			RequestDispatcher disp = ctx.getRequestDispatcher("showException.jsp");
			disp.forward(req, resp);
		}
	}
}
